@@ -1,6 +1,6 @@
 # --
 # Kernel/System/DynamicFieldValue.pm - DynamicField values backend
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -89,7 +89,8 @@ sub new {
     $Self->{CacheObject} = Kernel::System::Cache->new( %{$Self} );
 
     # get the cache TTL (in seconds)
-    $Self->{CacheTTL} = int( $Self->{ConfigObject}->Get('DynamicField::CacheTTL') || 60 * 60 * 12 );
+    $Self->{CacheTTL}
+        = int( $Self->{ConfigObject}->Get('DynamicField::CacheTTL') || 60 * 60 * 12 );
 
     return $Self;
 }
@@ -98,7 +99,7 @@ sub new {
 
 sets a dynamic field value. This is represented by one or more rows in the dynamic_field_value
 table, each storing one text, date and int field. Please see how they will be returned by
-L<ValueGet()>.
+L</ValueGet()>.
 
     my $Success = $DynamicFieldValueObject->ValueSet(
         FieldID  => $FieldID,                 # ID of the dynamic field
@@ -123,10 +124,7 @@ sub ValueSet {
     # check needed stuff
     for my $Needed (qw(FieldID ObjectID Value)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
             return;
         }
     }
@@ -240,10 +238,7 @@ sub ValueGet {
     # check needed stuff
     for my $Needed (qw(FieldID ObjectID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
             return;
         }
     }
@@ -260,21 +255,28 @@ sub ValueGet {
         Key  => $CacheKey,
     );
 
-    # Check if a cache entry exists for the given FieldID
-    if ( ref $Cache eq 'HASH' && exists $Cache->{ $Param{FieldID} } ) {
-        return $Cache->{ $Param{FieldID} };
+    # Check if a cache entry exists
+    if ( ref $Cache eq 'HASH' ) {
+
+        if ( exists $Cache->{ $Param{FieldID} } ) {
+            return $Cache->{ $Param{FieldID} };
+        }
+        return [];
     }
 
+    # We'll populate cache with all object's dynamic fields to reduce
+    # number of db accesses (only one db query for all dynamic fields till
+    # cache expiration); return only specified one dynamic field
     return if !$Self->{DBObject}->Prepare(
         SQL =>
-            'SELECT id, value_text, value_date, value_int
+            'SELECT id, value_text, value_date, value_int, field_id
             FROM dynamic_field_value
-            WHERE field_id = ? AND object_id = ?
+            WHERE object_id = ?
             ORDER BY id',
-        Bind => [ \$Param{FieldID}, \$Param{ObjectID} ],
+        Bind => [ \$Param{ObjectID} ],
     );
 
-    my @Result;
+    my %CacheData;
 
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
 
@@ -287,7 +289,7 @@ sub ValueGet {
             $Data[2] =~ s/^(\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}:\d{2})\..+?$/$1/;
         }
 
-        push @Result, {
+        push @{ $CacheData{ $Data[4] } }, {
             ID            => $Data[0],
             ValueText     => $Data[1],
             ValueDateTime => $Data[2],
@@ -295,28 +297,19 @@ sub ValueGet {
         };
     }
 
-    if ( ref $Cache eq 'HASH' ) {
-
-        # Cache file for ObjectID already exists, add field data.
-        $Cache->{ $Param{FieldID} } = \@Result;
-    }
-    else {
-
-        # Create new cache file.
-        $Cache = {
-            $Param{FieldID} => \@Result,
-        };
-    }
-
     # set cache
     $Self->{CacheObject}->Set(
         Type  => 'DynamicFieldValue',
         Key   => $CacheKey,
-        Value => $Cache,
+        Value => \%CacheData,
         TTL   => $Self->{CacheTTL},
     );
 
-    return \@Result;
+    if ( exists $CacheData{ $Param{FieldID} } ) {
+        return $CacheData{ $Param{FieldID} }
+    }
+
+    return [];
 }
 
 =item ValueDelete()
@@ -340,17 +333,14 @@ sub ValueDelete {
     # check needed stuff
     for my $Needed (qw(FieldID ObjectID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
             return;
         }
     }
 
     # delete dynamic field value
     return if !$Self->{DBObject}->Do(
-        SQL  => 'DELETE FROM dynamic_field_value WHERE field_id = ? AND object_id = ?',
+        SQL => 'DELETE FROM dynamic_field_value WHERE field_id = ? AND object_id = ?',
         Bind => [ \$Param{FieldID}, \$Param{ObjectID} ],
     );
 
@@ -379,10 +369,7 @@ sub AllValuesDelete {
     # check needed stuff
     for my $Needed (qw(FieldID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
             return;
         }
     }
@@ -449,8 +436,7 @@ sub ValueValidate {
 
         if ( $Value{ValueInt} !~ m{\A  -? \d+ \z}smx ) {
             $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Invalid Integer '$Value{ValueInt}'!"
+                Priority => 'error', Message => "Invalid Integer '$Value{ValueInt}'!"
             );
 
             return;
@@ -485,10 +471,7 @@ sub HistoricalValueGet {
     # check needed stuff
     for my $Needed (qw(FieldID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
             return;
         }
     }
@@ -560,10 +543,7 @@ sub _DeleteFromCache {
     # check needed stuff
     for my $Needed (qw(FieldID ObjectID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
             return;
         }
     }
