@@ -1,6 +1,6 @@
 # --
 # Kernel/System/EventHandler.pm - global object events
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,18 +21,16 @@ Kernel::System::EventHandler - event handler interface
 
 Inherit from this class if you want to use events there.
 
-    use vars qw(@ISA);
-    use Kernel::System::EventHandler;
-    push @ISA, 'Kernel::System::EventHandler';
+    use base qw(Kernel::System::EventHandler);
 
-In your class, have to call L<EventHandlerInit()> first.
+In your class, have to call L</EventHandlerInit()> first.
 
-Then, to register events as they occur, use the L<EventHandler()>
+Then, to register events as they occur, use the L</EventHandler()>
 method. It will call the event handler modules which are registered
 for the given event, or queue them for later execution (so-called
 'Transaction' events).
 
-In the destructor, you should add a call to L<EventHandlerTransaction()>
+In the destructor, you should add a call to L</EventHandlerTransaction()>
 to make sure that also 'Transaction' events will be executed correctly.
 This is only neccessary if you use 'Transaction' events in your class.
 
@@ -230,6 +228,7 @@ sub EventHandler {
                 #   processed.
             }
             else {
+
                 # This is the regular case. A new event was fired in regular mode, or
                 #   we are processing a queued event in transaction mode. Only execute
                 #   this if the transaction settings of event and listener are the same.
