@@ -1,7 +1,7 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 # --
 # bin/otrs.AddCustomerUser.pl - Add User from CLI
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -25,18 +25,8 @@ use warnings;
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . "/Kernel/cpan-lib";
-
-use vars qw (%opts);
-use Getopt::Std;
-getopt( 'flpgec', \%opts );
-unless ( $ARGV[0] ) {
-    print
-        "$FindBin::Script [-f firstname] [-l lastname] [-p password] [-g groupname] [-e email] [-c CustomerID] username\n";
-    print "\tif you define -g with a valid group name then the user will be added that group\n";
-    print "\n";
-    exit;
-}
+use lib dirname($RealBin) . '/Kernel/cpan-lib';
+use lib dirname($RealBin) . '/Custom';
 
 use Kernel::Config;
 use Kernel::System::Encode;
@@ -47,7 +37,7 @@ use Kernel::System::DB;
 use Kernel::System::CustomerUser;
 
 # create common objects
-my %CommonObject = ();
+my %CommonObject;
 $CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
 $CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
 $CommonObject{LogObject}
@@ -57,8 +47,18 @@ $CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
 $CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
 $CommonObject{UserObject} = Kernel::System::CustomerUser->new(%CommonObject);
 
+my %Options;
+use Getopt::Std;
+getopt( 'flpgec', \%Options );
+unless ( $ARGV[0] ) {
+    print
+        "$FindBin::Script [-f firstname] [-l lastname] [-p password] [-g groupname] [-e email] [-c CustomerID] username\n";
+    print "\tif you define -g with a valid group name then the user will be added that group\n";
+    print "\n";
+    exit;
+}
+
 my %Param;
-undef %Param;
 
 #user id of the person adding the record
 $Param{UserID} = '1';
@@ -67,12 +67,12 @@ $Param{UserID} = '1';
 $Param{ValidID} = '1';
 
 $Param{Source}         = 'CustomerUser';
-$Param{UserFirstname}  = $opts{f};
-$Param{UserLastname}   = $opts{l};
-$Param{UserCustomerID} = defined $opts{c} ? $opts{c} : $ARGV[0];
+$Param{UserFirstname}  = $Options{f};
+$Param{UserLastname}   = $Options{l};
+$Param{UserCustomerID} = defined $Options{c} ? $Options{c} : $ARGV[0];
 $Param{UserLogin}      = $ARGV[0];
-$Param{UserPassword}   = $opts{p};
-$Param{UserEmail}      = $opts{e};
+$Param{UserPassword}   = $Options{p};
+$Param{UserEmail}      = $Options{e};
 
 if ( $Param{UID} = $CommonObject{UserObject}->CustomerUserAdd( %Param, ChangeUserID => 1 ) ) {
     print "Customer user added. Username is $Param{UID}\n";
